Journal of Strength and Conditioning Research, 2001, 15(1), 109–115
� 2001 National Strength & Conditioning Association

## **A New Approach to Monitoring Exercise Training**

### **CARL FOSTER, JESSICA A. FLORHAUG, JODI FRANKLIN,** **LORI GOTTSCHALL, LAURI A. HROVATIN, SUZANNE PARKER,** **PAMELA DOLESHAL, AND CHRISTOPHER DODGE**

_Department of Exercise and Sport Science, University of Wisconsin–La Crosse, Wisconsin 54601._

**ABSTRACT**

The ability to monitor training is critical to the process of
quantitating training periodization plans. To date, no method
has proven successful in monitoring training during multiple types of exercise. High-intensity exercise training is particularly difficult to quantitate. In this study we evaluate the
ability of the session rating of perceived exertion (RPE) method to quantitate training during non–steady state and prolonged exercise compared with an objective standard based
on heart rate (HR). In a 2-part design, subjects performed
steady state and interval cycle exercise or practiced basketball. Exercise bouts were quantitated using both the session
RPE method and an objective HR method. During cycle exercise, the relationship between the exercise score derived
using the session RPE method and the HR method was highly consistent, although the absolute score was significantly
greater with the session RPE method. During basketball,
there was a consistent relationship between the 2 methods
of monitoring exercise, although the absolute score was also
significantly greater with the session RPE method. Despite
using different subjects in the 2 parts of the study, the regression relationships between the session RPE method and
the HR method were nearly overlapping, suggesting the
broad applicability of this method. We conclude that the session RPE method is a valid method of quantitating exercise
training during a wide variety of types of exercise. As such,
this technique may hold promise as a mode and intensityindependent method of quantitating exercise training and
may provide a tool to allow the quantitative evaluation of
training periodization plans.

_**Key Words:**_ periodization, heart rate, perceived exertion, interval training, prolonged exercise

_**Reference Data:**_ Foster, C., J.A. Florhaug, J. Franklin, L.
Gottschall, L.A. Hrovatin, S. Parker, P. Doleshal, and
C. Dodge. A new approach to monitoring exercise
training. _J. Strength Cond. Res. 15(1):109–115. 2001._

#### **Introduction**

# M any studies have stressed the importance of thetraining load in enhancing athletic performance

and the changes in performance attributable to varying

periods of hard and easy training (2, 5, 6, 9, 11–15, 18–
20). These practicalities are reflected in the practice of
coaches who design highly detailed periodized training programs (10, 21). Unfortunately, although periodized training programs are in their essence quantitative, there has been great difficulty in finding a way
to effectively quantitate training using a single term.
Endurance athletes have often used the training volume (kilometers per week) as an index of training
with reasonable effectiveness (13, 15). However, measurement of training volume ignores the critical importance of high-intensity training bouts (17). For athletes training for strength and/or power, the use of
the volume of training is an inadequate tool because
of the overriding importance of intensity.
There have been several previous attempts at developing a single term for quantitating training. In the
late 1960s, Cooper (7) proposed the concept of ‘‘aerobics points,’’ which integrated exercise duration and
the absolute intensity of aerobic training activities. Although this approach was highly successful in terms
of guiding the nonathletic public into fitness exercise,
the lack of an index of the relative training intensity
(which is much more critical as an index of how likely
a given exercise bout is to induce a training effect)
dictated that this method would lack the ability to adequately describe the training load. Banister et al. (2,
9, 18) have developed the concept of the training impulse (TRIMP) as a strategy for integrating the components of training into a single term that allows a
systems analysis approach to training. This method
has shown great promise relative to understanding the
training response and has been extended by Busso et
al. (6), Foster et al. (11, 12, 14, 15), and Mujika et al.
(19, 20). There are at least 2 important limitations to
the TRIMP concept developed by Bannister et al. (2, 9,
18). First, although monitors with the capacity of integrating the heart rate (HR) responses over long periods of time are widely available, if an athlete forgets
to use his or her HR monitor or if the HR monitor has
a technical failure during the exercise bout, information regarding that training session is lost. Second, HR

109

110 Foster, Florhaug, Franklin, Gottschall, Hrovatin, Parker, Doleshal, and Dodge

is a comparatively poor method of evaluating very
high-intensity exercise such as weight training, highintensity interval training, and plyometric training.
Thus even with the most optimal HR monitoring strategy, integration of the TRIMP does not translate well
to very high-intensity exercise training. We have developed a modification of the rating of the perceived
exertion method (the session RPE), which uses RPE as
a marker of training intensity within the TRIMP concept (11, 12, 14, 15). This method has been shown to
be related to both HR and blood lactate markers of
exercise intensity (14). However, our previous evaluation of the session RPE method has been based primarily on responses during 30 minutes of steady state
exercise within a comparatively modest range of exercise intensities. Given the importance of both highintensity training and extensive training bouts within
the training plan of contemporary athletes, information regarding the stability of the session RPE method
vs. HR methods of monitoring training during exercise other than brief steady state exercise is important.
Accordingly, the intent of this study was to evaluate
the relationship of the session RPE- and HR-based
methods of monitoring training during different forms
of exercise training.

#### **Methods**

This study was conducted in 2 separate but related
parts. In the first part we chose a common conditioning activity that allowed good quantitative control of
the exercise performed (cycle ergometry). This allowed
an idealized approach to both steady state and interval
exercise that we felt would be generally representative
of a variety of conditioning activities. During this
phase of the study, the subjects were 12 well-trained,
recreational-level cyclists ( _m_ � 6, _F_ � 6). In the second
part, the subjects were members of a collegiate men’s
basketball team ( _n_ � 14). Each subject provided informed consent prior to participation, and the study
protocol was approved by the university institutional
review board. Some descriptive characteristics of the
subjects are provided in Tables 1 and 2.

_**Part 1**_

Prior to the experimental protocol, each subject was
evaluated during maximal incremental exercise on an
electrically braked cycle ergometer (Lode, Gronningen,
Netherlands). The subjects pedaled at freely chosen
revolutions per minute (rpm’s) within the range of 60–
80\. The test began at a power output of 50 W for men,
40 W for women over 60 kg body weight, and 30 W
for women under 60 kg body weight. The power output was increased by the same increment every 3 minutes until the subject could no longer continue. The
peak power output was interpolated based on the proportional time achieved during the terminal stage. Oxygen uptake (V \[˙\] O2) was measured using open-circuit

**Table 1.** Mean (� _SD_ ) characteristics of the subjects in
part 1.\*

Men Women

Age (yr)
Height (cm)
Weight (kg)
Percent fat
Peak power output (W)
Peak power output (W·kg \[�\]\[1\] )
Peak V \[˙\] O2 (L·min \[�\]\[1\] )
Peak V \[˙\] O2 (ml·min \[�\]\[1\] - kg \[�\]\[1\] )
Peak HR (b·min \[�\]\[1\] )
IAT power output (W)
IAT power output (W·kg \[�\]\[1\] )
IAT HR (b·min \[�\]\[1\] )

23.0 � 3.6

177 � 4

70.8 � 7.2

11.1 � 4.8

315 � 34

4.52 � 0.52

3.84 � 0.30

54.6 � 2.4

198 � 10

228 � 25

3.28 � 0.65

174 � 19

21.3 � 1.5

165 � 8

63.8 � 4.3

20.9 � 2.7

237 � 33

3.68 � 0.38

2.94 � 0.34

46.2 � 3.5

186 � 7

188 � 48

2.94 � 0.61

159 � 16

- HR � heart rate; IAT � individual aerobic threshold.

**Table 2.** Mean (� _SD_ ) characteristics of the subjects in
Part 2.

Age (yr)
Height (cm)
Weight (kg)
Percent fat
Peak V \[˙\] O2 (L·min \[�\]\[1\] )
Peak V \[˙\] O2 (ml·min \[�\]\[1\] - kg \[�\]\[1\] )
Ventilatory threshold (L·min \[�\]\[1\] )

Age (yr) 20.2 � 1.5
Height (cm) 191.4 � 4.9
Weight (kg) 89.3 � 7.8
Percent fat 12.8 � 2.8
Peak V \[˙\] O2 (L·min \[�\]\[1\] ) 4.60 � 0.50
Peak V \[˙\] O2 (ml·min \[�\]\[1\] - kg \[�\]\[1\] ) 51.5 � 2.2
Ventilatory threshold (L·min \[�\]\[1\] ) 3.32 � 0.54

Respiratory compensation threshold
(L·min \[�\]\[1\] ) 3.71 � 0.44
HRpeak (b·min \[�\]\[1\] ) 182 � 9
HR at VT (b·min \[�\]\[1\] ) 136 � 6
HR at RCT (b·min \[�\]\[1\] ) 150 � 4

182 � 9

136 � 6

150 � 4

- HR � heart rate.

spirometry (Quinton Q-Plex, Seattle, WA). Peak V \[˙\] O2
was defined as the highest continuous full minute V \[˙\] O2
observed during the test. HR was measured by radiotelemetry (Polar Electro Oy, Port Washington, NY).
Blood lactate was measured in capillary blood obtained from a fingertip at rest, at the end of each stage
of exercise, and at 1, 3, 5, and 10 minutes postexercise
using an enzyme electrode system (YSI Sport, Yellow
Springs, OH). The individual anaerobic threshold
(IAT) was calculated on the basis of the exercise and
recovery blood lactate concentrations according to
Stegmann et al. (22).
Subsequently, each subject performed 8 randomly
ordered exercise training bouts, which included a reference 30-minute steady state bout at a power output
equivalent to 90% of the IAT, 2 additional steady state
exercise bouts at the same power output but of 60- and
90-minutes duration, and 5 interval bouts at the same
mean power output. The interval bouts were 30 minutes in duration and included variations in interval

**Figure 1.** Modification of the category ratio rating of perceived exertion (RPE) scale for this study. The verbal anchors have been changed slightly to reflect American idiomatic English (e.g., light becomes easy; strong or severe becomes hard). Briefly, the athlete is shown the scale approximately 30 minutes following the conclusion of the training
bout and asked ‘‘How was your workout?’’ In our experience, approximately 80–90% of athletes will give a single
number representing the training session. The remaining
athletes usually insist on fractionating and summating the
component parts of the session.

magnitude (�10, �25, and �50% of mean power output with a constant 60-seconds/60-seconds exercise/
recovery schedule) and in interval duration (0.5 minutes/0.5 minutes, 1.0 minute/1.0 minute, and 2.0 minutes/2.0 minutes with a constant �25% difference in
mean power output for exercise/recovery). Throughout each exercise bout, HR was measured by radiotelemetry. At rest and at 10-minute intervals, blood lactate was measured in capillary blood obtained from a
fingertip and perceived exertion was obtained using
the category ratio (e.g., 0–10) RPE scale of Borg (4).
Thirty minutes following the completion of each exercise bout, the subject was shown the RPE scale with
verbal anchors (Figure 1) and asked to provide a rating
of the overall difficulty of the exercise bout, the session
RPE. We have previously used this method in studies
of monitoring exercise training (11, 12, 14, 15). This
use of the RPE method is somewhat different than the
conventional approach that asks the subject to rate
with highly standardized verbal instructions how difficult they perceived the exercise to be at a particular
moment. Rather, we explained to the subject that we
wanted a global rating of the entire training bout using whatever cues they felt to be appropriate. We de

Monitoring Exercise Training 111

**Figure 2.** Schematic representation of the summated HR
zone method that serves as the objective basis for comparison for the session RPE method. Five HR zones are calculated based on percentages of the HR peak: 50–60% (zone
1); 60–70% (zone 2); 70–80% (zone 3); 80–90% (zone 4);
and 90–100% (zone 5). After the exercise session, the HR
monitor is downloaded and the cumulated time is each
zone is calculated. The time in each zone is then multiplied
by the value for that zone and the results summated.

layed securing the session RPE rating for 30 minutes
so that particularly difficult or particularly easy segments toward the end of the exercise bout would not
dominate the subject’s rating. In this context, it is important to note that the momentary RPE during the
interval bouts often varied quite substantially based on
the momentary activity pattern. However, the session
RPE represents a single global rating of the intensity
for the entire training session. We have not encountered difficulties with the subjects understanding our
intent, particularly with the slightly modified verbal
anchors presented in Figure 1, either in this study or
in our previous work with this technique (11, 12, 14,
15).
An exercise score (e.g., TRIMP) for each bout was
computed by multiplying the duration of the exercise
bout by the session RPE for that bout. As an objective
reference method for quantitating each exercise bout,
the HR monitor was downloaded using software that
allowed evaluation of the accumulated time in each of
5 HR zones based on 50–60%, 60–70%, 70–80%, 80–
90%, and 90–100% of HRpeak, as suggested by Edwards (8) and used in our previous work (11, 12, 14,
15). An exercise score (e.g., TRIMP) for that bout was
then computed by multiplying the accumulated duration in each HR zone by a multiplier for each zone
(50–60% � 1; 60–70% � 2; 70–80% � 3; 80–90% � 4;
and 90–100% � 5) and summating the result (Figure
2).

_**Part 2**_

Prior to the experimental protocol, each subject was
evaluated during incremental treadmill exercise using
an Astrand protocol. Exercise was continued to volitional fatigue. V \[˙\] O2 was measured using open-circuit
spirometry and V \[˙\] O2peak was defined as the highest

112 Foster, Florhaug, Franklin, Gottschall, Hrovatin, Parker, Doleshal, and Dodge

**Table 3.** Serial (mean � _SD_ ) responses of the outcome measures.

Steady state 0.5 m/0.5 m 1.0 m/1.0 m 2.0 m/ 2.0 m �10% �25% �50%

Heart rate (b·min \[�\]\[1\] )

Rest 79 � 13

10 m 155 � 10

20 m 159 � 11

30 m 160 � 13

60 m 164 � 12

90 m 166 � 9

Blood lactate (mmol·l \[�\]\[1\] )

Rest 1.1 � 0.5

10 m 2.8 � 0.8

20 m 2.8 � 0.8

30 m 2.5 � 0.8

60 m 2.3 � 0.7

90 m 2.2 � 0.6

Rating of perceived exertion

Rest 0.0 � 0.0

10 m 2.8 � 0.8

20 m 3.8 � 1.2

30 m 3.8 � 1.1

60 m 4.3 � 1.0

90 m 4.9 � 1.0

77 � 11

137 � 16

140 � 17

163 � 16

—

—

0.9 � 0.3

2.9 � 0.6

3.0 � 0.8

2.8 � 0.7

—

—

0.0 � 0.0

3.2 � 1.0

4.0 � 1.2

4.2 � 1.5

—

—

84 � 9

159 � 9

155 � 14

169 � 11

—

—

1.5 � 0.6

4.4 � 1.8\*

4.2 � 1.4\*

3.8 � 1.6\*

—

—

0.0 � 0.0

3.5 � 0.7

4.2 � 0.9

4.2 � 0.9

—

—

79 � 6

153 � 10

158 � 11

163 � 9

—

—

1.0 � 0.2

2.7 � 0.9

2.7 � 0.8

2.2 � 0.9

—

—

0.0 � 0.0

3.4 � 1.1

3.6 � 1.1

3.8 � 1.1

—

—

82 � 10

155 � 13

164 � 11\*

170 � 13\*

—

—

1.1 � 0.5

4.8 � 1.0\*

4.9 � 1.3\*

5.6 � 1.5\*

—

—

0.0 � 0.0

3.9 � 1.0\*

4.4 � 1.1\*

5.4 � 1.2\*

—

—

84 � 9

159 � 9

166 � 14\*

169 � 11\*

—

—

1.5 � 0.6

4.4 � 1.8\*

4.2 � 1.4\*

3.8 � 1.6\*

—

—

0.0 � 0.0

3.5 � 0.7

4.2 � 0.9

4.2 � 0.9

—

—

- _p_ � 0.05 compared to steady state.

continuous 60-second V \[˙\] O2 during the exercise bout.
Ventilatory and respiratory compensation thresholds
were determined according to changes in the slopes of
the V \[˙\] CO2 vs. V \[˙\] O2 and V \[˙\] E vs. V \[˙\] CO2 relationships, respectively (3). HR was measured using radiotelemetry.
Subsequently, each subject was monitored during
basketball practice sessions and/or during competitive
matches. The pattern of exercise during these bouts
was determined either by the coach’s plan or by the
dictates of the competitive situation. No attempt was
made to experimentally influence the pattern of exercise. HR responses were recorded during each exercise
bout using radiotelemetry, downloaded, and analyzed
using the summated HR zone approach as in Part 1
of the study. Thirty minutes following the conclusion
of each exercise bout, the subject rated the overall difficulty of the bout using the session RPE method, as
in Part 1 of the study.

_**Statistical Analyses**_
Statistical analysis focused on comparing the exercise
scores obtained during each exercise bout using the
session RPE and summated HR zone methods of
quantitating exercise training. This was accomplished
using repeated-measures analysis of variance (ANOVA). Post hoc analyses were performed using the Tukey procedure. Additionally, regression analyses were
performed to relate the 2 methods of quantitating exercise training.

82 � 12

166 � 12\*

169 � 12\*

172 � 14\*

—

—

1.5 � 0.8

3.7 � 1.2\*

3.4 � 1.5\*

3.9 � 1.4\*

—

—

0.0 � 0.0

4.1 � 0.9\*

4.3 � 0.8

4.4 � 1.1\*

—

—

#### **Results**

_**Part 1**_

The serial responses of HR, blood lactate, and RPE
through the course of the 8 exercise bouts are presented in Table 3. Given that the mean power output
was the same at 90% IAT in all exercise bouts, the differences in HR, blood lactate, and RPE were consistent
with previously established responses during interval
training and during prolonged exercise (1, 16, 23).
There was a consistent pattern for longer intervals,
more variable intervals, and longer duration steady
state exercise bouts to be associated with greater evidence of psychophysiological strain, evidenced by HR
and blood lactate concentrations.
Comparisons of the overall exercise score between
the summated HR zone method and the session RPE
method are presented in Table 4. There were significant differences between the methods for each exercise
bout, with the session RPE method consistently giving
a larger exercise score than the summated HR zone
method. However, regression analyses revealed that
the pattern of differences was highly consistent among
the various exercise bouts (Figure 3).

_**Part 2**_

The comparative exercise score using the summated
HR zone method and session RPE method during basketball practices and/or games is presented in Table

**Table 4.** Comparison of calculated exercise TRIMP scores
using the summated heart rate (HR) zone method and the
session rate of perceived exertion (RPE) method.

Summated HR

zone Session RPE

30 min steady state
60 min steady state
90 min steady state
30 s/30 s interval
60 s/60 s interval
120 s/120 s interval
�10% interval

�25% interval

�50% interval

Basketball

110 � 24

216 � 39

350 � 44

107 � 14

117 � 18

114 � 17

114 � 16

117 � 18

114 � 111

652 � 59

130 � 57\*

270 � 63\*

432 � 67\*

131 � 45\*

148 � 54\*

146 � 47\*

136 � 60\*

148 � 54\*

161 � 46\*

744 � 84\*

- _p_ � 0.05 summated HR zone vs. session RPE.

**Figure 3.** Regression lines comparing the relationship between TRIMP scores generated using the summated HR
zone method and session RPE method of monitoring exercise during the various cycle exercise bouts and during
basketball practice and competition. Note the overall similarity among the different exercise bouts, and that although
different subjects are used there is a similarity of the cycling and basketball data.

4. There were significant differences between the
   methods, with the session RPE method giving a larger
   exercise score than the summated HR method. However, regression analyses revealed that the pattern of
   differences was consistent and similar to responses
   during steady state and interval cycle exercise observed in Part 1 (Figure 3).

#### **Discussion**

The results of this study are consistent with our previous observations of a highly correlated relationship
between the session RPE and the summated HR zone
methods of evaluating training sessions (11, 12, 14).
This suggests that either method may be used as a
method of creating a TRIMP score for the evaluation
of exercise training. The methods are not, however, interchangeable because of differences in scale. The sum

Monitoring Exercise Training 113

mated HR zone method is based on only 5 zones, so
an athlete working at maximal HR for the entire duration of an exercise bout would only have their exercise duration multiplied by 5, whereas with 10 effective zones represented by the session RPE method the
multiplier for exercise duration can be somewhat larger, particularly at high intensities. In this regard, it is
worth noting that Banister et al. (2, 9, 18) used a nonlinear multiplier for the mean HR recorded during exercise, which is conceptually quite similar to the category ratio RPE score. Thus although the quality of information available from the session RPE method is
fairly crude relative to the highly detailed data available from HR records, the present data suggests that
the same critical information is contained with both
methods. The simplicity of the session RPE method
suggests the practical value of the technique.
Our experience with the session RPE method suggests that most athletes can use the technique fairly
well with only minimal instruction, primarily by focusing on the verbal anchors associated with the RPE
scale while responding to the simple question ‘‘How
was your workout?’’ Approximately 20% of athletes
will attempt to separately report RPE-duration scores
for various phases of each training session, which may
then be summated. The remaining 80% of athletes will
comfortably give a single number representing the gestalt of the training session. Despite these differences,
we have found that individual athletes seem to be very
consistent in their own pattern of using the session
RPE method, and that regardless of whether they are
detail-oriented or more globally focused, there is a
good relationship between their reports of training
load and subsequent performance (12). Previous work,
which we have done with this technique, has suggested that other data (monotony, strain) may be derived
from the session RPE–derived TRIMP scores reported
by the athletes (11, 15). Although one suspects that
similar data may be derived from HR-based TRIMP
scores, to date this has not been accomplished.
The overall consistency between objective (summated HR zone) and subjective (session RPE) methods
of monitoring training during highly disparate types
of exercise suggests that the session RPE method may
be useful over a very wide variety of exercise sessions.
Previous experience with RPE as a method of monitoring exercise suggests that muscularly strong individuals are comparatively poor at rating the intensity
of aerobic exercise sessions, attending more to muscular tension than to sensations of dyspnea. However,
when providing an overall gestalt with familiar modes
of training, it may be that even athletes performing
highly intense muscular activities can provide adequate ratings. Although ultrahigh-intensity exercise
(resistance training, plyometrics) cannot objectively be
evaluated using HR criteria, the pattern of responses
between objective and subjective measures in the pre

114 Foster, Florhaug, Franklin, Gottschall, Hrovatin, Parker, Doleshal, and Dodge

**Table 5.** Schematic training diary demonstrating the calculation of training load, monotony, and strain.

Day Training activity

Session rate of
perceived
exertion Duration
(RPE) (min) Load

Sunday
Monday
Tuesday

Wednesday
Thursday
Friday
Saturday

Cycle 100 km
Jog 5 km � extensive stretch
Skate 6 � 10 min at AT pace/5 min rec
Explosive weights � abs
Cycle 30 km
Skate 10 � 3 min at 5 km pace/5-min rec
Jog 5 km � extensive stretch
Skate 20 � 1 min at tempo/2-min rec
Explosive weights � abs

Weekly load
Monotony (� _SD_ )
Strain (load � monotony)

5\*

2\*

7\*

7\*

3\*

8\*

2\*

8\*

7\*

940

50

840

280

180

390

50

390

280

3400

1.26

4284

180

25

120

40

60

75

25

75

40

**Figure 4.** Schematic training periodization plan over the
17 weeks leading up to a major weekend of competition.
Note the day to day variation in the training load and the
weekly variation in training. With this scheme of monitoring training, the coach can appreciate how well the athlete
executes the designed periodization plan. In particular, the
failure of the athlete to progressively increment the
‘‘heavy’’ weeks of the training plan is very obvious and
explains the less than satisfactory results at the time of the
competitions.

sent data (where the power output of the �50% ergometer trials and during basketball practice occasionally exceeded the peak aerobic power output) suggests
that the session RPE method might be a valid approach to evaluating even very high-intensity exercise.
If this were so, then a single method could be used to
provide a quantitative basis for describing the periodization of training plans. Some support for this suggestion is provided by the relationship between training load and performance, which we have previously
demonstrated with speed skaters (who do a wide variety of aerobic, interval, and ultrahigh-intensity train

ing; 11, 12). Finally, the session RPE method has the
advantage of not requiring knowledge of maximal exercise responses (e.g., HRpeak) to anchor the monitoring method. Although in athletic individuals determination of maximal HR is relatively risk-free, it still
represents an additional step in designing a training
monitoring scheme that is not required by the session
RPE method.

#### **Practical Applications**

The present data provide support for the use of the
session RPE method as a subjective estimate of training load during non–steady state exercise, including
very high-intensity interval training and team sport
practice and competition. As such, it suggests that this
very simple method may be a useful technique for
quantitating training load in a wide variety of athletic
applications. In this regard, the present data suggest
that the session RPE method may provide a mechanism for quantitating the exercise intensity component
and allow calculation of a single number representative of the combined intensity and duration of training
sessions.
The present data and our previous experience with
the session RPE technique suggest that it is easy to use,
quite reliable, and consistent with objective physiological indices of the intensity of exercise training. By simply asking the athlete to rate the global intensity of the
exercise bout and then by multiplying by the duration
of the training bout, a daily exercise score can be created. This can be put into the form of an exercise diary,
which can reveal the overall weekly pattern of exercise
(Table 5). From this, accessory indices of training, such
as monotony and strain, can be calculated, potentially
providing in index of the likelihood of untoward training outcomes. Finally, the daily and weekly training

loads calculated using this technique can be presented
graphically, allowing the coach to have a visual impression of the periodization plan as experienced by
the athlete (Figure 4).

#### **References**

1. BANGSBO, J. Physiology of intermittent exercise. In: _Exercise and_
   _Sport Science_ W.E. Garrett and D.T. Kirkendall, eds. Philadelphia: Lippincott, Williams and Wilkins, 2000. pp. 31–52.

1. BANISTER, E.W., T.W. CLAVERT, M.V. SAVAGE, AND T. BACH. A
   systems model of training for athletic performance. _Aust. J._
   _Sports Med._ 7:57–61. 1975.

1. BEAVER, W.L., K. WASSERMAN, AND B.J. WHIPP. A new method
   for detecting the anaerobic threshold by gas exchange. _J. Appl._
   _Physiol._ 60:2020–2027. 1986.

1. BORG, G., P. HASSMEN, AND M. LANGERSTROM. Perceived exertion in relation to heart rate and blood lactate during arm
   and leg exercise. _Eur. J. Appl. Physiol._ 65:679–685. 1985.

1. BROWN, D.D. Pulmonary responses to exercise and training. In:
   _Exercise and Sport Science._ W.E. Garrett and D.T. Kirkendall, eds.
   Philadelphia: Lippincott, Williams and Wilkins, 2000. pp. 117–

1.

1. BUSSO, T., C. DENIS, R. BONNEFOY, A. GEYSSANT, AND J.R. LA
   COUR. Modeling of adaptations to physical training by using a
   recursive least squares algorithm. _J. Appl. Physiol._ 82:1685–1693.

1.

1. COOPER, K.H. _Aerobics._ New York: Bantam, 1968.

1. EDWARDS, S. _The Heart Rate Monitor Book._ Sacramento: Fleet Feet
   Press, 1993. pp. 113–129.

1. FITZ-CLARAKE, J.R., R.H. MORTON, AND E.W. BANISTER. Optimizing athletic performance by influence curves. _J. Appl. Phy-_
   _siol._ 71:1151–1158. 1991.

1. FLECK, S.J. Periodized strength training: A critical review. _J._
   _Strength Cond. Res._ 13:82–89. 1999.

1. FOSTER, C. Monitoring training in athletes with reference to overtraining syndrome. _Med. Sci. Sports Exerc._ 30:1164–1168. 1997.

Monitoring Exercise Training 115

12. FOSTER, C., E. DANIES, L. HECTOR, A. SNYDER, AND R. WELSH.
    Athletic performance in relation to training load. _Wis. Med. J._
    95:370–374. 1996.
01. FOSTER, C., J. DANIELS, AND R. YARBROUGH. Physiological and
    training correlates of marathon running performance. _Aust. J._
    _Sports Med._ 9:58–61. 1977.
01. FOSTER, C., L. HECTOR, R. WELSH, M. SCHRAGER, M.A. GREEN,

AND A.C. SNYDER. Effects of specific versus cross training on
running performance. _Eur. J. Appl. Physiol._ 70:367–372. 1995.
15\. FOSTER, C., AND M. LEHMANN. Overtraining syndrome. In:
_Running Injuries._ G. Guten, ed. Orlando: W.B. Saunders, Co.,
1997\. pp. 173–188.
16\. GOROSTIAGA, E.M., C.B. WALTER, C. FOSTER, AND R.C. HICK
SON. Uniqueness of interval and continuous training at the
same maintained exercise intensity. _Eur. J. Appl. Physiol._ 63:101–
107\. 1991.

17. LINDSAY, F.H., J.A. HAWLEY, K.H. MYBURGH, H.H. SCHOMEN,
    T.D. NOAKES, AND S.C. DENNIS. Improved athletic performance
    in highly trained cyclists after interval training. _Med. Sci. Sports_
    _Exerc._ 28:1427–1434. 1996.

01. MORTON, R.H., J.R. FITZ-CLARKE, AND E.W. BANISTER. Modeling human performance in running. _J. Appl. Physiol._ 69:1171–

01. 1990.

01. MUJIKA, I. The influence of training characteristics and tapering
    on the adaptations in highly trained individuals. A review. _Int._
    _J. Sports Med._ 19:439–436. 1996.

01. MUJIKA, I., T. BUSSO, L. LACOSTE, A.G. BARALE, AND J.C. CHA
    TARD. Modeled responses to training and taper in competitive
    swimmers. _Med. Sci. Sports Exerc._ 28:252–258. 1996.

01. ROWBOTTOM, D. Periodization of training. In: _Exercise and Sport_
    _Science._ W.E. Garret and D.T. Kirkendall, eds. Philadelphia: Lippincott, Williams and Wilkins, 2000. pp. 499–512.

01. STEGMANN, H., W. KINDERMANN, AND A. SCHNABEL. Lactate
    kinetics and individual anaerobic threshold. _Int. J. Sports Med._
    2:160–165. 1981.

01. VUORIMAA, T., T. VASANKARI, AND H. RUSKO. Comparison of
    physiological strain and muscular performance of athletes during 2 intermittent running exercises at the velocity associated
    with V \[˙\] O2max. _Int. J. Sports Med._ 21:96–101. 2000.
